/** 
 *   Thermometer logger novus
 *
 *   (c) Copyright 2005 Federico Bareilles <fede@iar.unlp.edu.ar>,
 *   Instituto Argentino de Radio Astronomia (IAR).
 *
 *   This program is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU General Public License as
 *   published by the Free Software Foundation; either version 2 of
 *   the License, or (at your option) any later version.
 *     
 *   The author does NOT admit liability nor provide warranty for any
 *   of this software. This material is provided "AS-IS" in the hope
 *   that it may be useful for others.
 *
 **/


#include <stdio.h>
#include <stdlib.h>
#include <getopt.h>
#include "my_stdio.h"
#include "logger_novus.h"
#include "modbus.h"


int dump_conf_flag = 0;

#ifdef DEBUG_MODE
int print_pk2(char *from, unsigned char *buff, int len, int x0 )
{
	int i;
	int j = 0;
	int l = 0;

	j = 0;
	printf("%-6s(%2d):\n", from, len);
	printf("   |");	for(i=0;i<8;i++)printf("   %d   |", i);
	printf("\n---+");	for(i=0;i<8;i++)printf("-------+");
	printf("\n");
	printf("%3d| ", l);
	for(i=x0;i<len;i++) {
		printf("%02x", buff[i]);
		if ( (i-x0) % 2) {
			printf(" | ");
			j++;
			if ( ((j) % 8) == 0) {
				l+=8;
				printf("\n%3d| ", l);
			}
		}else{
			printf(" ");
		}
	}
	printf("\n");

	fflush(stdout);

	return 0;
}
#endif


int main(int argc, char * const argv[])
{
	int i;
	int op;
	char *device = LOGGER_NOVUS_DEVICE;
	int length;
	struct logger_nv lnv;
	
	while  ((op = getopt(argc, argv, "cvhd:")) != EOF)
		switch( op ){
#ifdef VERBOSE_MODE
		case 'v':
			verbose_flag = (verbose_flag << 1) | 1;
			break;
		case 'c':
			dump_conf_flag = 1;
			break;
#endif

		case 'd':
			device = optarg;
			break;
		case 'h':
		default:
			printf("Use: [-cvh] [-d device]\n");
			exit(-1);
		}
	lnv.slave = 1;
	if( logger_init(&lnv, device) < 0) {
		printf("Can't open: %s\n", device);
		return -1;
	}
#ifdef DEBUG_MODE
	if (dump_conf_flag) {
		print_pk2("logger", lnv.map, LOGGER_CONF_REG_LENGTH << 1, 0);
	}
#endif
	length  = logger_adq(&lnv);

	if(length > 0) {
		for(i=0;i<8;i++)
			if (lnv.thr[i].active) {
				printf("Ther %1d: %5.1f C\n",
				      i, lnv.thr[i].val);
			}
	}

	//logger_test(fd, ther_nv,length);
	//logger_test2(fd);
		
	logger_close(&lnv);


	return 0;
}


