/** 
 *   Thermometer logger novus
 *
 *   (c) Copyright 2005 Federico Bareilles <fede@iar.unlp.edu.ar>,
 *   Instituto Argentino de Radio Astronomia (IAR).
 *
 *   This program is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU General Public License as
 *   published by the Free Software Foundation; either version 2 of
 *   the License, or (at your option) any later version.
 *     
 *   The author does NOT admit liability nor provide warranty for any
 *   of this software. This material is provided "AS-IS" in the hope
 *   that it may be useful for others.
 *
 **/

#ifndef __LOGER_NOVUS_H
#define __LOGER_NOVUS_H

#include "modbus.h"

#define LOGGER_SLAVE 1
#define LOGGER_NOVUS_DEVICE "/dev/logger_nv"

#define THERMOCOUPLE_J  0x01
#define THERMOCOUPLE_K  0x02
#define THERMOCOUPLE_T  0x03
#define THERMOCOUPLE_E  0x04
#define THERMOCOUPLE_N  0x05
#define THERMOCOUPLE_R  0x06
#define THERMOCOUPLE_S  0x07
#define THERMOCOUPLE_B  0x08
#define PT100           0x09

#define LOGGER_CONF_REG_LENGTH 201
//#define LOGGER_CONF_MAP_LENGTH (LOGGER_CONF_REG_LENGTH << 1)
#define RELAY_0_ENABLE  0x20
#define RELAY_1_ENABLE  0x40
#define CHANNEL_ENABLE  0x80
#define LABEL_ENABLE    0x08


struct logger_input {
	//int channel; //FIXME: Eliminar
	char label[9];
	int type; /* FIXME: No esta implementado, falta decodificarlo */
	int active;
	double val;
	double alarm;
	int al_type;
};


struct logger_nv {
	char label[17];
	int slave;
	int fd;
	unsigned char map[LOGGER_CONF_REG_LENGTH << 1];
	struct logger_input thr[8];
	int relay0; /* 0: alarm, 1: digital output */
	int relay1; /* 0: alarm, 1: digital output */
	int num_act_thr;
	/* ... */
};

int logger_init(struct logger_nv *lnv, char *device);
int logger_close(struct logger_nv *lnv);
int logger_adq(struct logger_nv *lnv);
int logger_set_reg(struct logger_nv *lnv, int reg, int val);
int logger_get_reg(struct logger_nv *lnv, int reg, int *val);
int logger_get_conf(struct logger_nv *lnv);
int logger_relay(struct logger_nv *lnv, int relay, int state);
int logger_relay_on(struct logger_nv *lnv, int relay);
int logger_relay_off(struct logger_nv *lnv, int relay);
int logger_enable_relay(struct logger_nv *lnv, int relay);
int logger_disable_relay(struct logger_nv *lnv, int relay);

int logger_test(int fd, struct logger_input *tn, int length);
int logger_test2(int fd);

#endif /* __LOGER_NOVUS_H */

